Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(752)

Unified Diff: third_party/WebKit/Source/core/editing/CaretDisplayItemClient.cpp

Issue 2888253002: Skip both paint and raster invalidation for LayoutSVGHiddenContainer subtree (Closed)
Patch Set: Rebaseline-cl Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/editing/CaretDisplayItemClient.cpp
diff --git a/third_party/WebKit/Source/core/editing/CaretDisplayItemClient.cpp b/third_party/WebKit/Source/core/editing/CaretDisplayItemClient.cpp
index 9f72b807354135f6c9997164132aa6f159259efa..c7e4c1689894cb26f01b40d4942ed4588382092b 100644
--- a/third_party/WebKit/Source/core/editing/CaretDisplayItemClient.cpp
+++ b/third_party/WebKit/Source/core/editing/CaretDisplayItemClient.cpp
@@ -255,12 +255,12 @@ void CaretDisplayItemClient::InvalidatePaintInCurrentLayoutBlock(
// paint invalidation.
if (IsImmediateFullPaintInvalidationReason(
layout_block_->FullPaintInvalidationReason()) ||
// For non-SPv2, ForcedSubtreeInvalidationChecking may hint change of
// paint offset. See ObjectPaintInvalidatorWithContext::
// invalidatePaintIfNeededWithComputedReason().
(!RuntimeEnabledFeatures::slimmingPaintV2Enabled() &&
- (context.forced_subtree_invalidation_flags &
- PaintInvalidatorContext::kForcedSubtreeInvalidationChecking))) {
+ (context.subtree_flags &
+ PaintInvalidatorContext::kSubtreeInvalidationChecking))) {
object_invalidator.InvalidateDisplayItemClient(
*this, PaintInvalidationReason::kCaret);
}
@@ -255,12 +255,12 @@ void CaretDisplayItemClient::InvalidatePaintInCurrentLayoutBlock(
if (IsImmediateFullPaintInvalidationReason(
layout_block_->FullPaintInvalidationReason()) ||
- // For non-SPv2, ForcedSubtreeInvalidationChecking may hint change of
+ // For non-SPv2, kSubtreeInvalidationChecking may hint change of
// paint offset. See ObjectPaintInvalidatorWithContext::
// invalidatePaintIfNeededWithComputedReason().

Powered by Google App Engine
This is Rietveld 408576698